Module opt
deepwoken_
reqparse
0.1.2
Module opt
Module Items
Structs
In deepwoken_
reqparse::
model
deepwoken_reqparse
::
model
Module
opt
Structs

Optional
Group
Represents a group of requirements that are optional, but will be either all acquired or all not