pub struct OptionalGroup {
pub general: HashSet<Requirement>,
pub post: HashSet<Requirement>,
pub weight: i64,
}Expand description
Represents a group of requirements that are optional, but will be either all acquired or all not
Fields
general: HashSet<Requirement>post: HashSet<Requirement>weight: i64Implementations
Sourceimpl OptionalGroup
impl OptionalGroup
pub fn get_set(&mut self, timing: Timing) -> &mut HashSet<Requirement>