Stat

Enum Stat 

#[repr(u32)]
pub enum Stat {
Show 17 variants Strength = 0, Fortitude = 1, Agility = 2, Intelligence = 3, Willpower = 4, Charisma = 5, HeavyWeapon = 6, MediumWeapon = 7, LightWeapon = 8, Frostdraw = 9, Flamecharm = 10, Thundercall = 11, Galebreathe = 12, Shadowcast = 13, Ironsing = 14, Bloodrend = 15, Total = 16,
}

Variants



Strength = 0



Fortitude = 1



Agility = 2



Intelligence = 3



Willpower = 4



Charisma = 5



HeavyWeapon = 6



MediumWeapon = 7



LightWeapon = 8



Frostdraw = 9



Flamecharm = 10



Thundercall = 11



Galebreathe = 12



Shadowcast = 13



Ironsing = 14



Bloodrend = 15



Total = 16

A stat representing the total cost of all stats, aka the ‘Cost’ Can and should be used to model power levels

Implementations

Source

impl Stat

pub fn from_u32_unchecked(value: u32) -> Self

pub fn short_name(&self) -> &'static str

pub fn name(&self) -> &'static str

pub fn from_name(name: &str) -> Option<Self>

pub fn from_short_name(short: &str) -> Option<Self>

pub const fn is_attunement(&self) -> bool

pub const fn as_u32(self) -> u32

pub const fn as_i64(self) -> i64